==> saga-1.0.5.tgz: package/lib/tests/selectors.test.js <==
'use strict';

var _theme = require('bootstrap-styled/lib/theme');

var _theme2 = _interopRequireDefault(_theme);

var _asyncThemeReducer = require('../reducer/asyncThemeReducer');

var _selectors = require('../selectors');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

describe('selectBsSaga', function () {
  var state = void 0;
  var bsSagaState = void 0;

  beforeEach(function () {
    bsSagaState = _asyncThemeReducer.initialState;
    state = {
      'bs.saga': bsSagaState
    };
  });

  describe('selectBsSaga', function () {
    it('should select the bootstrap-styled-saga state', function () {
      expect((0, _selectors.selectBsSaga)(state)).toEqual(state['bs.saga']);
    });

    describe('selectAsyncThemes', function () {
      it('should select the async themes', function () {
        expect((0, _selectors.selectAsyncThemes)(state)).toEqual(bsSagaState.themes);
      });
    });

    describe('selectAsyncValues', function () {
      it('should select the async themes values', function () {
        expect((0, _selectors.selectAsyncValues)(state)).toEqual(Object.keys(bsSagaState.themes));
      });
    });
  });

  describe('selectBsRedux and selectBsSaga', function () {
    it('should select sync and async themes', function () {
      expect((0, _selectors.selectBsSaga)(state)).toEqual(state['bs.saga']);
    });

    describe('selectGroupedThemes', function () {
      var doubleState = {
        'bs.redux': {
          theme: _theme2.default,
          themes: _defineProperty({}, _theme2.default._name, _theme2.default)
        },
        'bs.saga': {
          themes: {
            copy: _theme2.default
          }
        }
      };
      it('should select the async themes', function () {
        var _expect$toEqual;

        expect((0, _selectors.selectGroupedThemes)(doubleState)).toEqual((_expect$toEqual = {}, _defineProperty(_expect$toEqual, _theme2.default._name, _theme2.default), _defineProperty(_expect$toEqual, 'copy', _theme2.default), _expect$toEqual));
      });
    });

    describe('selectGroupedValues', function () {
      var doubleState = {
        'bs.redux': {
          theme: _theme2.default,
          themes: _defineProperty({}, _theme2.default._name, _theme2.default)
        },
        'bs.saga': {
          themes: {
            copy: _theme2.default
          }
        }
      };
      it('should select the async themes', function () {
        expect((0, _selectors.selectGroupedValues)(doubleState)).toEqual(['copy', new String(_theme2.default._name)]); // eslint-disable-line no-underscore-dangle, no-new-wrappers
      });
    });
  });
});

==> saga-1.1.1.tgz: package/lib/tests/selectors.test.js <==
"use strict";

var _theme = _interopRequireDefault(require("bootstrap-styled/lib/theme"));

var _reducer = require("../reducer");

var _selectors = require("../selectors");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

describe('selectBsSaga', function () {
  var state;
  var bsSagaState;
  beforeEach(function () {
    bsSagaState = _reducer.initialState;
    state = {
      'bs.saga': bsSagaState
    };
  });
  describe('selectBsSaga', function () {
    it('should select the bootstrap-styled-saga state', function () {
      expect((0, _selectors.selectBsSaga)(state)).toEqual(state['bs.saga']);
    });
    describe('selectAsyncThemes', function () {
      it('should select the async themes', function () {
        expect((0, _selectors.selectAsyncThemes)(state)).toEqual(bsSagaState.themes);
      });
    });
    describe('selectAsyncValues', function () {
      it('should select the async themes values', function () {
        expect((0, _selectors.selectAsyncValues)(state)).toEqual(Object.keys(bsSagaState.themes));
      });
    });
  });
  describe('selectBsRedux and selectBsSaga', function () {
    it('should select sync and async themes', function () {
      expect((0, _selectors.selectBsSaga)(state)).toEqual(state['bs.saga']);
    });
    describe('selectGroupedThemes', function () {
      var doubleState = {
        'bs.redux': {
          theme: _theme.default,
          themes: _defineProperty({}, _theme.default._name, _theme.default)
        },
        'bs.saga': {
          themes: {
            copy: _theme.default
          }
        }
      };
      it('should select the async themes', function () {
        var _expect$toEqual;

        expect((0, _selectors.selectGroupedThemes)(doubleState)).toEqual((_expect$toEqual = {}, _defineProperty(_expect$toEqual, _theme.default._name, _theme.default), _defineProperty(_expect$toEqual, "copy", _theme.default), _expect$toEqual));
      });
    });
    describe('selectGroupedValues', function () {
      var doubleState = {
        'bs.redux': {
          theme: _theme.default,
          themes: _defineProperty({}, _theme.default._name, _theme.default)
        },
        'bs.saga': {
          themes: {
            copy: _theme.default
          }
        }
      };
      it('should select the grouped values', function () {
        expect((0, _selectors.selectGroupedValues)(doubleState)).toEqual(['copy', new String(_theme.default._name)]); // eslint-disable-line no-underscore-dangle, no-new-wrappers
      });
    });
  });
});
